import { type Ref } from 'vue-demi';
import { type MaybeRef, type MaybeRefOrGetter } from '@vueuse/shared';
import { Popup, type Content, type LatLngExpression, type Layer, type PointExpression, type PopupOptions } from 'leaflet';
import type { UpdateWatchSource } from '../useLeafletLayer';
export type LayerPopupReactiveProperty = 'offset' | 'maxWidth' | 'minWidth' | 'maxHeight' | 'className' | 'content' | 'keepInView' | 'autoPan' | 'autoPanPaddingTopLeft' | 'autoPanPaddingBottomRight' | 'autoPanPadding';
export interface UseLeafletLayerPopupOptions extends Omit<PopupOptions, LayerPopupReactiveProperty> {
    visible?: MaybeRef<boolean>;
    autoBind?: boolean;
    offset?: MaybeRefOrGetter<PointExpression | null | undefined>;
    maxWidth?: MaybeRefOrGetter<number | null | undefined>;
    minWidth?: MaybeRefOrGetter<number | null | undefined>;
    maxHeight?: MaybeRefOrGetter<number | null | undefined>;
    keepInView?: MaybeRefOrGetter<boolean | null | undefined>;
    autoPan?: MaybeRefOrGetter<boolean | null | undefined>;
    autoPanPaddingTopLeft?: MaybeRefOrGetter<PointExpression | null | undefined>;
    autoPanPaddingBottomRight?: MaybeRefOrGetter<PointExpression | null | undefined>;
    autoPanPadding?: MaybeRefOrGetter<PointExpression | null | undefined>;
    className?: MaybeRefOrGetter<string | null | undefined>;
    defOptions?: PopupOptions;
    updateSources?: UpdateWatchSource<Layer>[];
    dispose?: boolean;
}
export interface UseLeafletLayerPopupReturn {
    visible: Ref<boolean>;
    popup: {
        value: Popup | null;
    };
    bind: () => void;
    unbind: () => void;
    open: (latlng?: LatLngExpression) => void;
    close: () => void;
    toggle: () => void;
    isOpened: () => boolean;
}
export declare function useLeafletLayerPopup(source: MaybeRefOrGetter<Layer | null | undefined>, content?: MaybeRef<((layer: Layer) => Content) | Popup | Content | null | undefined>, options?: UseLeafletLayerPopupOptions): UseLeafletLayerPopupReturn;
